@@ -14,7 +14,7 @@
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
 
-from collections import defaultdict
+from collections import defaultdict, OrderedDict
 
 from cdpcli import ADDITIONAL_PROPERTIES
 from cdpcli import LIST_TYPE
@@ -23,7 +23,6 @@ from cdpcli import OBJECT_TYPE
 from cdpcli import REF_KEY
 from cdpcli import REF_NAME_PREFIX
 from cdpcli import TYPE_KEY
-from cdpcli.compat import OrderedDict
 from cdpcli.utils import CachedProperty
 from cdpcli.utils import instance_cache
 
@@ -153,7 +152,7 @@ class MapShape(Shape):
     def value(self):
         additional_properties = self._shape_data.get(ADDITIONAL_PROPERTIES)
         # Map with Freeform object
-        if type(additional_properties) == bool or not additional_properties:
+        if isinstance(additional_properties, bool) or not additional_properties:
             raise InvalidShapeError("Freeform maps are not supported: %s"
                                     % self.name)
         else:
@@ -171,6 +170,10 @@ class StringShape(Shape):
     def enum(self):
         return self._shape_data.get('enum', [])
 
+    @CachedProperty
+    def deprecated_enum_values(self):
+        return self._shape_data.get('x-deprecated-enum-values', [])
+
     @CachedProperty
     def supported_options(self):
         return self._shape_data.get('x-supported-options', [])
@@ -398,6 +401,12 @@ class ServiceModel(object):
     def form_factors(self):
         return self._service_data.get("x-form-factors", "public").split(',')
 
+    @CachedProperty
+    def extensions(self):
+        if "x-extensions" in self._service_data:
+            return self._service_data['x-extensions'].split(',')
+        return None
+
 
 class DenormalizedStructureBuilder(object):
     """Build a StructureShape from a denormalized model.
@@ -502,6 +511,8 @@ class DenormalizedStructureBuilder(object):
             shape['documentation'] = model['documentation']
         if 'enum' in model:
             shape['enum'] = model['enum']
+        if 'x-deprecated-enum-values' in model:
+            shape['x-deprecated-enum-values'] = model['x-deprecated-enum-values']
         if 'x-supported-options' in model:
             shape['x-supported-options'] = model['x-supported-options']
         if 'x-no-paramfile' in model:
